@@ -1,11 +1,10 @@
-package # hide from PAUSE
-Term::Choose::Constants;
+package Term::Choose::Constants;
 
 use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.206';
+our $VERSION = '1.207';
 
 use Exporter qw( import );
 
